cmoncrawl.aggregator.utils.ndjson\_decoder
==========================================

.. automodule:: cmoncrawl.aggregator.utils.ndjson_decoder

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      Decoder
   
   

   
   
   



